@@ -6,7 +6,7 @@
  
     :Example:
  
-    >>> import hades.aero.Isentropic as Is
+    >>> import aerokit.aero.Isentropic as Is
     >>> Is.TiTs_Mach(1.)
     1.2
     >>> Is.TiTs_Mach(2., gamma=1.6)
@@ -17,12 +17,12 @@
  
     Provides Ti/Ts Pi/Ps ratios from Mach number and reversed functions.
     Specific heat ratio `gamma` is optionnal and can be specified in the functions itself
-    or using hades.common.defaultgas module
+    or using aerokit.common.defaultgas module
  """
 
 
 import numpy               as np
-import flowdyn.modelphy.base as model
+#import flowdyn.modelphy.base as model
 #import flowdyn.mesh          as mesh
 import flowdyn.field         as field
 
@@ -144,7 +144,7 @@ class fvm1d(base):
         self.residual = []
         for i in range(self.neq):
             self.residual.append(-(self.flux[i][1:self.nelem+1]-self.flux[i][0:self.nelem]) \
-                                  /(self.mesh.xf[1:self.nelem+1]-self.mesh.xf[0:self.nelem]))
+                                  /(self.mesh.dx()))
         return self.residual
 
     def add_source(self):
